==> portal-contribuinte-3.158.0.zip: BOOT-INF/classes/sql/simam/validacaoarquivo/deducaoCreditoDA.sql <==
with contagemdeducaocredito as (select nrdeducao, nranodeducao, count(1) as qtdregistrosdeducaoda from tcededucaocreditoda group by nrdeducao, nranodeducao),
contagemdivida as (select nranodeducao, nrdivida, nranodivida, idtipodeducaocredito, cdcontroleleiato, dtdeducao, count(1) as qtdregistrosdivida from tcededucaocreditoda group by nranodeducao, nrdivida, nranodivida, idtipodeducaocredito , cdcontroleleiato, dtdeducao)
select 	tdcda.idtcededucaocreditoda,
		tdcda.nrdeducao,
		tdcda.nranodeducao,
		ticda.nrdivida,
		ticda.nranodivida,
		ttd.tipodeducao,
		tdcda.cdcontroleleiato,
		tdcda.dtdeducao,
		tdcda.vldeducao,
		tdcda.dsmotivo,
		ticda.dtinscricao,
		cd.qtdregistrosdivida,
		cdc.qtdregistrosdeducaoda,
		tel.codigo as escopolei,
        coalesce(lag(tdcda.nrdeducao, 1) over (order by idtcededucaocreditoda), 0) as nrdeducaoanterior
from tcededucaocreditoda tdcda
join contagemdeducaocredito cdc on cdc.nrdeducao = tdcda.nrdeducao and cdc.nranodeducao = tdcda.nranodeducao
left join contagemdivida cd on cd.nranodeducao = tdcda.nranodeducao
and cd.nrdivida = tdcda.nrdivida
and cd.nranodivida = tdcda.nranodivida
and cd.idtipodeducaocredito = tdcda.idtipodeducaocredito
and cd.cdcontroleleiato = tdcda.cdcontroleleiato
and cd.dtdeducao = tdcda.dtdeducao
left join tceinsccreditoda ticda on ticda.nrdivida = tdcda.nrdivida and ticda.nranodivida = tdcda.nranodivida
left join tribtipodeducao ttd on ttd.tipodeducao = tdcda.idtipodeducaocredito
left join cgato cg on cg.entidade = :entidade and cg.idato = tdcda.cdcontroleleiato
left join tipoescopolei tel on tel.id = cg.idtipoescopolei
where tdcda.dtdeducao between :dataInicial and :dataFinal

==> portal-contribuinte-3.326.0.zip: BOOT-INF/classes/sql/simam/validacaoarquivo/deducaoCreditoDA.sql <==
with contagemdeducaocredito as (select nrdeducao, nranodeducao, count(1) as qtdregistrosdeducaoda from tcededucaocreditoda group by nrdeducao, nranodeducao),
contagemdivida as (select nranodeducao, nrdivida, nranodivida, idtipodeducaocredito, cdcontroleleiato, dtdeducao, count(1) as qtdregistrosdivida from tcededucaocreditoda group by nranodeducao, nrdivida, nranodivida, idtipodeducaocredito , cdcontroleleiato, dtdeducao)
select 	tdcda.idtcededucaocreditoda,
		tdcda.nrdeducao,
		tdcda.nranodeducao,
		ticda.nrdivida,
		ticda.nranodivida,
		ttd.tipodeducao,
		tdcda.cdcontroleleiato,
		tdcda.dtdeducao,
		tdcda.vldeducao,
		tdcda.dsmotivo,
		ticda.dtinscricao,
		coalesce(cd.qtdregistrosdivida, 1) as qtdregistrosdivida,
		cdc.qtdregistrosdeducaoda,
		tel.codigo as escopolei,
        coalesce(lag(tdcda.nrdeducao, 1) over (order by idtcededucaocreditoda), 0) as nrdeducaoanterior
from tcededucaocreditoda tdcda
join contagemdeducaocredito cdc on cdc.nrdeducao = tdcda.nrdeducao and cdc.nranodeducao = tdcda.nranodeducao
left join contagemdivida cd on cd.nranodeducao = tdcda.nranodeducao
and cd.nrdivida = tdcda.nrdivida
and cd.nranodivida = tdcda.nranodivida
and cd.idtipodeducaocredito = tdcda.idtipodeducaocredito
and cd.cdcontroleleiato = tdcda.cdcontroleleiato
and cd.dtdeducao = tdcda.dtdeducao
left join tceinsccreditoda ticda on ticda.nrdivida = tdcda.nrdivida and ticda.nranodivida = tdcda.nranodivida
left join tribtipodeducao ttd on ttd.tipodeducao = tdcda.idtipodeducaocredito
left join cgato cg on cg.entidade = :entidade and cg.idato = tdcda.cdcontroleleiato
left join tipoescopolei tel on tel.id = cg.idtipoescopolei
where tdcda.dtdeducao between :dataInicial and :dataFinal
